pub type Id = u64;
pub type FileSize = u64;
pub type ImageDimension = u64;

#[derive(serde::Deserialize, Clone, Debug)]
pub struct Posts {
    #[serde(alias = "posts")]
    inner: Vec<Post>
}

impl Into<Vec<Post>> for Posts {
    fn into(self) -> Vec<Post> {
        self.inner
    }
}


#[derive(serde::Deserialize, Clone, Debug)]
pub struct Post {
    id: Id,
    created_at: String,
    updated_at: String,
    tags: PostTags, 
    file: PostFile,
    rating: String,
    fav_count: u16,
    sources: Vec<String>,
    approver_id: Option<Id>,
    uploader_id: Id,
    description: String,
    comment_count: u16,
    has_notes: bool,
    is_favorited: bool,
    change_seq: Option<u128>,
    relationships: PostRelationships
}

#[derive(serde::Deserialize, Clone, Debug)]
pub struct PostTags {
    general: Vec<String>,
    artist: Vec<String>,
    copyright: Vec<String>,
    character: Vec<String>,
    invalid: Vec<String>,
    meta: Vec<String>,
    lore: Vec<String>
}

#[derive(serde::Deserialize, Clone, Debug)]
pub struct PostFile {
    width: ImageDimension,
    height: ImageDimension,
    ext: String,
    size: FileSize,
    md5: String,
    url: String
}

#[derive(serde::Deserialize, Clone, Debug)]
pub struct PostRelationships {
    parent_id: Option<Id>,
    has_children: bool,
    has_active_children: bool,
}
